pub enum ObjectKind {
Unknown,
Link,
Export,
Import,
Resource,
Assembly,
CPP,
C,
}Expand description
Defines the kinds of objects.
Rich records can identify the product used and with it the ‘language’ of the objects. This allows a mapping of products and the kind of ‘language’ it was generated from.
Variants
Unknown
Link
Export
Exported symbol.
Import
Imported symbol.
Resource
Resource object.
Assembly
Assembly object.
CPP
C++ object.
C
C object.