RichStructure

Struct RichStructure 

pub struct RichStructure<'a> { /* private fields */ }
Rich structure.

Implementations

Source

impl<'a> RichStructure<'a>

pub fn image(&self) -> &'a [u32]

Returns the Rich image without the padding.

pub fn checksum(&self) -> u32

Calculate the checksum.

The checksum should be equal to the xor key.

pub fn xor_key(&self) -> u32

Gets the xor key.

pub fn records(&self) -> RichIter<'a>

Gets the records.

pub fn encode( &self, records: &[RichRecord], dest: &mut [u32], ) -> Result<usize, usize>

Encodes a new set of records.

If the destination does not have the right len, returns Err with the right len. Call encode again with destination of the returned len, destination is not modified.

Returns Ok with the len of the destination when encoding was successful.