pub struct RichStructure<'a> { /* private fields */ }Expand description
Rich structure.
Implementations
Sourceimpl<'a> RichStructure<'a>
impl<'a> RichStructure<'a>
Sourcepub fn checksum(&self) -> u32
pub fn checksum(&self) -> u32
Calculate the checksum.
The checksum should be equal to the xor key.
Sourcepub fn encode(
&self,
records: &[RichRecord],
dest: &mut [u32],
) -> Result<usize, usize>
pub fn encode( &self, records: &[RichRecord], dest: &mut [u32], ) -> Result<usize, usize>
Encodes a new set of records.
If the destination does not have the right len, returns Err with the right len. Call encode again with destination of the returned len, destination is not modified.
Returns Ok with the len of the destination when encoding was successful.